@@ -2,7 +2,7 @@
 # Test Results
 ###############################################
 
-f <- LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_mu, mu)
+f <- LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_mu, mu, 15)
 test_that("Check structure.", {
   expect_true(class(f) == "function")
   expect_true(all(names(formals(f)) == c("x", "mu", "alternative", "conf.level")))
@@ -24,58 +24,21 @@ test_that("calc_test_stat input checking works", {
 })
 rm(calc_test_helper_one, calc_test_helper_two, calc_test_helper_three)
 
+test_that("n_min input checking works", {
+  expect_error(LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_sigma.squared, sigma.squared, "asdf"), "n_min should be numeric.")
+  expect_error(LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_sigma.squared, sigma.squared, c(1, 2)), "n_min should have length one.")
+  expect_error(LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_sigma.squared, sigma.squared, -2), "n_min should be greater than one.")
+})
+
 test_that("LB input checking works", {
-  expect_error(LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_sigma.squared, sigma.squared, "asdf"), "LB should be numeric.")
-  expect_error(LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_sigma.squared, sigma.squared, c(1, 2)), "LB should have length one.")
+  expect_error(LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_sigma.squared, sigma.squared, 45, "asdf"), "LB should be numeric.")
+  expect_error(LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_normal_sigma.squared, sigma.squared, 45, c(1, 2)), "LB should have length one.")
 })
 
 ###############################################
 # Test Results
 ###############################################
-calc_test_stat <- function(x, fctr) {
-  obs_mean <- base::mean(x)
-
-  profile_sd <- (sum((x - obs_mean)^2) / length(x))^.5
-
-  group_means <- vector(mode = "numeric", length = length(levels(fctr)))
-
-  W1 <- sum(stats::dnorm(x = x, mean = obs_mean, sd = profile_sd, log = TRUE))
-
-  for (i in seq_along(levels(fctr))) {
-    l <- levels(fctr)[i]
-    index <- which(fctr == l)
-    tempX <- x[index]
-    temp <- base::mean(tempX)
-    group_means[i] <- temp
-    names(group_means)[i] <- l
-  }
-
-  SS <- 0
-  for (i in seq_along(levels(fctr))) {
-    l <- levels(fctr)[i]
-    index <- which(fctr == l)
-    tempX <- x[index]
-    tempSS <- sum((tempX - group_means[i])^2)
-    SS <- SS + tempSS
-  }
-  profile_sd_ha <- (SS / length(x))^.5
-
-  likelihoods <- vector(mode = "numeric", length = length(group_means))
-  for (i in seq_along(levels(fctr))) {
-    l <- levels(fctr)[i]
-    index <- which(fctr == l)
-    tempX <- x[index]
-    temp <- sum(stats::dnorm(x = tempX, mean = group_means[i], sd = profile_sd_ha, log = TRUE))
-    likelihoods[i] <- temp
-  }
-  W2 <- sum(likelihoods)
-
-  W <- 2 * (W2 - W1)
-
-  return(W)
-}
-
-f <- LRTesteR:::create_test_function_one_way_case_one(calc_test_stat, gaussian_mu_one_sample)
+f <- LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, gaussian_mu_one_sample, 30)
 test_that("Check structure.", {
   expect_true(class(f) == "function")
   expect_true(all(names(formals(f)) == c("x", "fctr", "conf.level")))
@@ -102,10 +65,16 @@ helper_two <- function(x, mu, typo, conf.level) {}
 helper_three <- function(x, mu, alternative, typo) {}
 helper_four <- function(x, mu, alternative, conf.level, extra) {}
 test_that("calc_test_stat input checking works", {
-  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat, 1), "Argument calc_individual_CI must be a function.")
-  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat, helper_one), "calc_individual_CI's first argument is not x.")
-  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat, helper_two), "calc_individual_CI's third argument is not alternative.")
-  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat, helper_three), "calc_individual_CI's fourth argument is not conf.level.")
-  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat, helper_four), "calc_individual_CI has too many arguments.")
+  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, 1), "Argument calc_individual_CI must be a function.")
+  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, helper_one), "calc_individual_CI's first argument is not x.")
+  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, helper_two), "calc_individual_CI's third argument is not alternative.")
+  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, helper_three), "calc_individual_CI's fourth argument is not conf.level.")
+  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, helper_four), "calc_individual_CI has too many arguments.")
 })
 rm(helper_one, helper_two, helper_three, helper_four)
+
+test_that("n_min input checking works", {
+  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, gaussian_mu_one_sample, "asdf"), "n_min should be numeric.")
+  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, gaussian_mu_one_sample, c(1, 2)), "n_min should have length one.")
+  expect_error(LRTesteR:::create_test_function_one_way_case_one(calc_test_stat_normal_mu_one_way, gaussian_mu_one_sample, -2), "n_min should be greater than three.")
+})
